@@ -260,8 +260,8 @@ namespace Nes
 			NST_SINGLE_CALL void Lxa (uint);
 			NST_SINGLE_CALL void Sbx (uint);
 			NST_SINGLE_CALL uint Shs (uint);
-			NST_SINGLE_CALL uint Shx (uint);
-			NST_SINGLE_CALL uint Shy (uint);
+			NST_SINGLE_CALL void Shx (uint);
+			NST_SINGLE_CALL void Shy (uint);
 
 			NST_NO_INLINE void Anc (uint);
 			NST_NO_INLINE uint Dcp (uint);
@@ -487,8 +487,6 @@ namespace Nes
 			Ram ram;
 			Apu apu;
 			IoMap map;
-			bool cpuOverclocking;
-			uint extraCycles;
 
 			static dword logged;
 			static void (Cpu::*const opcodes[0x100])();
@@ -501,12 +499,6 @@ namespace Nes
 				return apu;
 			}
 
-			void SetOverclocking(bool overclocking,uint newCycles)
-			{
-				cpuOverclocking = overclocking;
-				extraCycles = newCycles;
-			}
-
 			Cycle Update(uint readAddress=0)
 			{
 				apu.ClockDMA( readAddress );
